<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id" sourcelanguage="en_US">
<context>
    <name>ManualProxy</name>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="363"/>
        <source>Learn Basic Operations</source>
        <translation>Belajar Operasi Dasar</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="366"/>
        <source>Common Application Libraries</source>
        <translation>Pustaka Aplikasi Umum</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="369"/>
        <source>Desktop Environment</source>
        <translation>Lingkungan Meja</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/view/widget/search_completion_window.cpp" line="197"/>
        <source>Search for "%1" in the full text</source>
        <translation>Cari "%1" dalam teks seluruhnya</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="363"/>
        <source>The content was updated</source>
        <translation>Isi telah diperbarui</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="767"/>
        <source>Search</source>
        <translation>Pencarian</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="35"/>
        <source>Support</source>
        <translation>Dukungan</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="1038"/>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
        <source>Quick Start</source>
        <translation>Mulai Cepat</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
        <source>Video Guide</source>
        <translation>Panduan Video</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
        <source>Applications</source>
        <translation>Aplikasi</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
        <source>No search results</source>
        <translation>Tidak ada hasil pencarian</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
        <source>Home</source>
        <translation>Home</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
        <source>  result</source>
        <translation>hasil</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
        <source>  results</source>
        <translation>hasil</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="33"/>
        <source>Click to view </source>
        <translation>Klik untuk melihat </translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="34"/>
        <source>View all</source>
        <translation>Lihat semua</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="36"/>
        <source>App Store</source>
        <translation>Toko Aplikasi</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="136"/>
        <source>Manual</source>
        <translation>Manual</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="137"/>
        <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
        <translation>Manual dirancang untuk membantu pengguna mempelajari sistem operasi dan aplikasinya, memberikan instruksi serta deskripsi fungsi yang spesifik.</translation>
    </message>
</context>
<context>
    <name>WebWindow</name>
    <message>
        <location filename="../src/view/web_window.cpp" line="952"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="969"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
</context>
</TS>
